CONTENT constant
int
const CONTENT
Variable defined as a Content Optimizer content variable in the Insider panel.
Implementation
static const int CONTENT = 0;
Variable defined as a Content Optimizer content variable in the Insider panel.
static const int CONTENT = 0;