ELEMENT constant
int
const ELEMENT
Variable defined as a Content Optimizer element variable in the Insider panel.
Implementation
static const int ELEMENT = 1;
Variable defined as a Content Optimizer element variable in the Insider panel.
static const int ELEMENT = 1;