InsiderAppCardDeeplinkAction class

Inheritance

Constructors

InsiderAppCardDeeplinkAction({String? urlScheme, String? internalBrowserUrl, String? externalBrowserUrl, Map<String, dynamic>? json, List<Map<String, String>>? keysAndValues})

Properties

actionType String
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
json Map<String, dynamic>?
no setter
keysAndValues List<Map<String, String>>?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map) InsiderAppCardDeeplinkAction?