ContentOptimizerDataType class
Data type identifiers for the Content Optimizer API.
Pass one of these constants as the dataType argument to
FlutterInsider.getContentStringWithName,
FlutterInsider.getContentIntWithName, or
FlutterInsider.getContentBoolWithName to choose which Insider variable
pool to read from.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited