InsiderCloseButtonPosition class
Position values accepted by FlutterInsider.setInternalBrowserCloseButtonPosition.
Controls where the close (X) button is rendered inside the Insider internal browser.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- LEFT → String
-
Render the close button in the top-left corner.
final
- NONE → String
-
Hide the close button entirely.
final
- RIGHT → String
-
Render the close button in the top-right corner.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited